MeldPlanItem class final

Constructors

MeldPlanItem({required Float64List a, required Float64List centeredA, required Float64List transformedB, required Float64List orientedB, required (double, double) centerA, required (double, double) centerB, required double theta, required double logScale, required double residual, required bool closed, int? sourceIndex, int? targetIndex, BlockTransport? block})

Properties

a Float64List
final
block BlockTransport?
final
centerA → (double, double)
final
centerB → (double, double)
final
centeredA Float64List
final
closed bool
final
hashCode int
The hash code for this object.
no setterinherited
logScale double
final
orientedB Float64List
final
residual double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceIndex int?
Index of the normalized source contour used for this pair.
final
targetIndex int?
Index of the normalized target contour used for this pair.
final
theta double
final
transformedB Float64List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited