MeldFrame class final

Constructors

MeldFrame({required Iterable<Float64List> paths, required double progress, required double velocity})

Properties

hashCode int
The hash code for this object.
no setterinherited
paths List<Float64List>
final
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
velocity double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited